pycocoa.panels.TextPanel

Package pycocoa :: Module panels :: Class TextPanel |
[frames] | no frames]

# Class TextPanel

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                baseTypes._Type1 --+
                                   |
                    baseTypes._Type2 --+
                                       |
                              AlertPanel --+
                                           |
                                          TextPanel

Scrollable text panel Python Type, wrapping ObjC `NSAlert`.

Instance Methods
__init__(self, title=`'``Text Panel``'`) Create a TextPanel. |
show(self, text_or_file='', font=None, help='', timeout=None) Show alert message iff not suppressed. |
Inherited from `baseTypes._Type2`: `__str__` Inherited from `baseTypes._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `baseTypes._Type2`: `title` Inherited from `baseTypes._Type1`: `NSdelegate`, `app` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, title=`'``Text Panel``'`) (Constructor) |
Create a TextPanel. Parameters: `title` - The panel name and title (`str`). Raises: `ValueError` - Multi-line info or too long. Overrides: object.__init__

### show(self, text_or_file='', font=None, help='', timeout=None) |
Show alert message iff not suppressed. Parameters: `text_or_file` - The contents (`str` or `file`). `font` - Optional font (Font), default `Fonts.MonoSpace`. `help` - Optional, help text (`str`). `timeout` - Optional time limit (`float`). Returns: The button clicked (`PanelButton.Close`) or `PanelButton.TimedOut` if the timeout expired. Raises: `ValueError` - No text_or_file given. Overrides: AlertPanel.show